@@ -47,6 +47,7 @@
 #include "empathy-avatar-chooser.h"
 #include "empathy-avatar-image.h"
 #include "empathy-ui-utils.h"
+#include "empathy-string-parser.h"
 #include "empathy-kludge-label.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
@@ -552,6 +553,7 @@ contact_widget_location_update (EmpathyContactWidget *information)
   };
   int i;
   const gchar *skey;
+  gboolean display_map = FALSE;
 
   if (!(information->flags & EMPATHY_CONTACT_WIDGET_SHOW_LOCATION))
     {
@@ -666,20 +668,30 @@ contact_widget_location_update (EmpathyContactWidget *information)
       row++;
     }
 
-  if (row == 0)
+#if HAVE_LIBCHAMPLAIN
+  if (has_position &&
+      !(information->flags & EMPATHY_CONTACT_WIDGET_FOR_TOOLTIP))
     {
+      /* Cannot be displayed in tooltips until Clutter-Gtk can deal with such
+       * windows */
+      display_map = TRUE;
+    }
+#endif
+
+  if (row > 0)
+    {
+      /* We can display some fields */
+      gtk_widget_show (information->table_location);
+    }
+  else if (!display_map)
+    {
+      /* Can't display either fields or map */
       gtk_widget_hide (information->vbox_location);
       return;
     }
 
-  gtk_widget_show (information->table_location);
-
 #if HAVE_LIBCHAMPLAIN
-  /* Cannot be displayed in tooltips until Clutter-Gtk can deal with such
-   * windows
-   */
-  if (has_position &&
-      !(information->flags & EMPATHY_CONTACT_WIDGET_FOR_TOOLTIP))
+  if (display_map)
     {
       ClutterActor *marker;
       ChamplainLayer *layer;
@@ -690,8 +702,10 @@ contact_widget_location_update (EmpathyContactWidget *information)
 
       gtk_container_add (GTK_CONTAINER (information->viewport_map),
           information->map_view_embed);
-      g_object_set (G_OBJECT (information->map_view), "show-license", FALSE,
+      g_object_set (G_OBJECT (information->map_view),
+          "show-license", TRUE,
           "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
+          "zoom-level", 10,
           NULL);
 
       layer = champlain_layer_new ();
@@ -935,8 +949,15 @@ contact_widget_name_notify_cb (EmpathyContactWidget *information)
 static void
 contact_widget_presence_notify_cb (EmpathyContactWidget *information)
 {
-  gtk_label_set_text (GTK_LABEL (information->label_status),
-      empathy_contact_get_status (information->contact));
+  const gchar *status;
+  gchar *markup_text = NULL;
+
+  status = empathy_contact_get_status (information->contact);
+  if (status != NULL)
+    markup_text = empathy_add_link_markup (status);
+  gtk_label_set_markup (GTK_LABEL (information->label_status), markup_text);
+  g_free (markup_text);
+
   gtk_image_set_from_icon_name (GTK_IMAGE (information->image_state),
       empathy_icon_name_for_contact (information->contact),
       GTK_ICON_SIZE_BUTTON);
